@@ -1,5 +1,4 @@
 {-# LANGUAGE MagicHash, BangPatterns #-}
-{-# OPTIONS_GHC -O0 #-}
 
 import Foreign.C
 import Data.Word
@@ -11,7 +10,7 @@ import Control.Exception
 hashStr  :: Ptr Word8 -> Int -> Int
 hashStr (Ptr a#) (I# len#) = loop 0# 0#
    where
-    loop h n | n GHC.Exts.==# len# = I# h
+    loop h n | isTrue# (n GHC.Exts.==# len#) = I# h
              | otherwise  = loop h2 (n GHC.Exts.+# 1#)
           where !c = ord# (indexCharOffAddr# a# n)
                 !h2 = (c GHC.Exts.+# (h GHC.Exts.*# 128#)) `remInt#` 4091#
