@@ -33,7 +33,7 @@ import Control.Exception (assert)
 import Control.Monad
 import Control.Monad.Trans.State.Strict
 import Control.Monad.Trans.Class
-import GHC.Exts
+import GHC.Exts hiding (IsList(..))
 import GHC.ST hiding (liftST)
 import Prelude hiding (length, read)
 import qualified Prelude as P
@@ -361,7 +361,7 @@ cloneMArraySlow !marr !off n =
 -- Utilities for simplifying RNG passing
 
 newtype Rng s a = Rng { unRng :: StateT StdGen (ST s) a }
-                deriving Monad
+                deriving (Functor, Applicative, Monad)
 
 -- Same as 'randomR', but using the RNG state kept in the 'Rng' monad.
 rnd :: Random a => (a, a) -> Rng s a
