@@ -5,5 +5,5 @@ module T3101 where
 
 type family F a :: *
 
-data Boom = Boom (forall a. F a)
+data Boom = Boom (forall a. a -> F a)
   deriving Show
