@@ -6,7 +6,7 @@
 module Main where
 
 newtype Wrap m a = Wrap { unWrap :: m a } 
-    deriving (Monad, Eq)
+    deriving (Functor, Applicative, Monad, Eq)
 
 foo :: Int -> Wrap IO a -> Wrap IO ()
 foo 0 a = return ()
