@@ -8,7 +8,7 @@ import Language.Haskell.Extension
 
 main :: IO ()
 main = do
-    let ghcExtensions = [ ext | (ext, _, _) <- xFlags ]
+    let ghcExtensions = map flagSpecName xFlags
         cabalExtensions = map show [ toEnum 0 :: KnownExtension .. ]
         ghcOnlyExtensions = ghcExtensions \\ cabalExtensions
         cabalOnlyExtensions = cabalExtensions \\ ghcExtensions
@@ -30,22 +30,10 @@ check title expected got
          showProblems "Missing flags" missing
 
 expectedGhcOnlyExtensions :: [String]
-expectedGhcOnlyExtensions = ["ParallelArrays",
-                             "RelaxedLayout",
-                             "DeriveGeneric",
-                             "DefaultSignatures",
-                             "InterruptibleFFI",
+expectedGhcOnlyExtensions = ["RelaxedLayout",
                              "AlternativeLayoutRule",
                              "AlternativeLayoutRuleTransitional",
-                             "MonadComprehensions",
-                             "TraditionalRecordSyntax",
-                             "DataKinds",
-                             "PolyKinds",
-                             "ExplicitNamespaces",
-                             "InstanceSigs",
-                             "CApiFFI",
-                             "LambdaCase",
-                             "MultiWayIf"]
+                             "StaticPointers"]
 
 expectedCabalOnlyExtensions :: [String]
 expectedCabalOnlyExtensions = ["Generics",
@@ -57,5 +45,6 @@ expectedCabalOnlyExtensions = ["Generics",
                                "RegularPatterns",
                                "SafeImports",
                                "Safe",
+                               "Unsafe",
                                "Trustworthy"]
 
