@@ -20,7 +20,6 @@ import Unsafe.Coerce
 import Control.Monad
 import Data.Maybe
 import Bag
-import PrelNames (iNTERACTIVE)
 import Outputable
 import GhcMonad
 import X
@@ -52,7 +51,7 @@ chaseConstructor :: (GhcMonad m) => HValue -> m ()
 chaseConstructor !hv = do
   dflags <- getDynFlags
   liftIO $ putStrLn "====="
-  closure <- liftIO $ getClosureData hv
+  closure <- liftIO $ getClosureData dflags hv
   case tipe closure  of
     Indirection _ -> chaseConstructor (ptrs closure ! 0)
     Constr -> do
