@@ -1,4 +1,4 @@
-{-# LANGUAGE ExistentialQuantification #-}
+{-# LANGUAGE ExistentialQuantification, DeriveDataTypeable #-}
 
 -- The second version (count2) took ages with GHC 6.12
 -- because the typeOf function was not properly memoised
@@ -44,7 +44,4 @@ main = do
   doTime $ count1 x
   doTime $ count1 x
 
-data T = MkT
-tcname :: TyCon
-tcname = mkTyCon "T"
-instance Typeable T where { typeOf _ = mkTyConApp tcname [] }
+data T = MkT deriving Typeable
