@@ -2,5 +2,5 @@
 {-# OPTIONS_GHC -Wall -Werror #-}
 module Bug(P) where
 
-newtype P a = P (IO a) deriving Monad
+newtype P a = P (IO a) deriving (Functor, Applicative, Monad)
 
