@@ -1,5 +1,4 @@
 {-# LANGUAGE FlexibleInstances #-}
-{-# LANGUAGE OverlappingInstances #-}
 {-# LANGUAGE Safe #-}
 
 -- Untrusted plugin! Don't wan't it changing behaviour of our
@@ -8,10 +7,10 @@ module SafeLang10_B where
 
 import SafeLang10_A
 
-instance Pos a where
+instance {-# OVERLAPPABLE #-} Pos a where
     res _ = False
 
-instance Pos [Int] where
+instance {-# OVERLAPPING #-} Pos [Int] where
     res _ = error "This curry is poisoned!"
 
 function :: Int
