@@ -4,6 +4,8 @@
 
 module T4203 where
 
+import Control.Applicative (Applicative(..))
+import Control.Monad (liftM, ap)
 
 newtype NonNegative a = NonNegative a
  deriving (Eq, Num, Show)
@@ -26,6 +28,13 @@ instance Arbitrary EmptyStackSet where
 
 newtype Gen a = Gen a
 
+instance Functor Gen where
+    fmap = liftM
+
+instance Applicative Gen where
+    pure = return
+    (<*>) = ap
+
 instance Monad Gen where
   return a    = Gen a
   Gen m >>= k = Gen (let Gen m' = k m in m')
