@@ -11,10 +11,10 @@ genAny decl = do { d <- decl
 	}
 
 genAnyClass :: Name -> [Dec] -> Dec
-genAnyClass name decls 
+genAnyClass name decls
   = DataD [] anyName [] [constructor] []
   where
     anyName = mkName ("Any" ++ nameBase name ++ "1111")
-    constructor = ForallC [PlainTV var_a] [ClassP name [VarT var_a]] $
+    constructor = ForallC [PlainTV var_a] [AppT (ConT name) (VarT var_a)] $
 		  NormalC anyName [(NotStrict, VarT var_a)]
     var_a = mkName "a"
