@@ -2,9 +2,12 @@
 
 module ShouldCompile() where
 
+foo x = x
+{-# NOINLINE [1] foo #-}
+
 -- Trac #2497; test should compile without language
 -- 	       pragmas to swith on the forall
-{-# RULES "id" forall (x :: a). id x = x #-}
+{-# RULES "id" forall (x :: a). foo x = x #-}
 
 
 
