@@ -6,6 +6,8 @@
 
 module Storage.Hashed.Monad () where
 
+import Control.Applicative (Applicative(..))
+
 class Monad m => TreeRO m where
     withDirectory :: (MonadError e m) => Int -> m a -> m a
     expandTo :: (MonadError e m) => Int -> m Int
@@ -18,6 +20,13 @@ instance (Monad m, MonadError e m) => TreeRO (M m) where
 
 data M (m :: * -> *) a
 
+instance Functor (M m) where
+    fmap = undefined
+
+instance Applicative (M m) where
+    pure = undefined
+    (<*>) = undefined
+
 instance Monad m => Monad (M m) where
     (>>=) = undefined
     return = undefined
