@@ -1,3 +1,4 @@
+{-# LANGUAGE FlexibleInstances, TypeSynonymInstances, UndecidableInstances #-}
 module Tc173a where
 
 class FormValue value where
@@ -8,10 +9,10 @@ class FormTextField value
 
 instance FormTextField String
 
-instance FormTextField value => FormTextFieldIO value
+instance {-# OVERLAPPABLE #-} FormTextField value => FormTextFieldIO value
 
 class FormTextFieldIO value
 
 instance FormTextFieldIO value => FormValue value
 
-instance FormTextFieldIO value => FormTextFieldIO (Maybe value)
+instance {-# OVERLAPPING #-} FormTextFieldIO value => FormTextFieldIO (Maybe value)
