@@ -1,4 +1,4 @@
-{-# LANGUAGE Rank2Types #-}
+{-# LANGUAGE RankNTypes #-}
 
 -- A classic test for type inference
 -- Taken from "Haskell and principal types", Section 3
@@ -6,6 +6,9 @@
 
 module ShouldCompile where
 
+import GHC.List (null)
+import Prelude hiding (null)
+
 class HasEmpty a where
   isEmpty :: a -> Bool
 
