@@ -1,6 +1,9 @@
 
 module T1735_Help.State where
 
+import Control.Monad (ap, liftM)
+
+
 newtype StateT s m a = StateT { runStateT :: s -> m (a,s) }
 
 instance Monad m => Monad (StateT s m) where
@@ -10,6 +13,13 @@ instance Monad m => Monad (StateT s m) where
         runStateT (k a) s'
     fail str = StateT $ \_ -> fail str
 
+instance Monad m => Functor (StateT s m) where
+    fmap = liftM
+
+instance Monad m => Applicative (StateT s m) where
+    pure  = return
+    (<*>) = ap
+
 get :: Monad m => StateT s m s
 get = StateT $ \s -> return (s, s)
 
